==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/LabSupportPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs.builder
import com.pulumi.azurenative.devtestlab.kotlin.enums.EnableStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of a lab's support banner
 * @property enabled Is the lab support banner active/enabled at this time?
 * @property markdown The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
 */
public data class LabSupportPropertiesArgs(
    public val enabled: Output<Either<String, EnableStatus>>? = null,
    public val markdown: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs =
        com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs.builder()
            .enabled(
                enabled?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .markdown(markdown?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LabSupportPropertiesArgs].
 */
@PulumiTagMarker
public class LabSupportPropertiesArgsBuilder internal constructor() {
    private var enabled: Output<Either<String, EnableStatus>>? = null

    private var markdown: Output<String>? = null

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("toxtbnxoefoewvta")
    public suspend fun enabled(`value`: Output<Either<String, EnableStatus>>) {
        this.enabled = value
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("ejuqwqohpdxswege")
    public suspend fun markdown(`value`: Output<String>) {
        this.markdown = value
    }

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("pcfdpbqktyapcdjk")
    public suspend fun enabled(`value`: Either<String, EnableStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("wlslemqnqnkuogjq")
    public fun enabled(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("neroymetthhpvqdn")
    public fun enabled(`value`: EnableStatus) {
        val toBeMapped = Either.ofRight<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("kboerrqrcjhqkpvm")
    public suspend fun markdown(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.markdown = mapped
    }

    internal fun build(): LabSupportPropertiesArgs = LabSupportPropertiesArgs(
        enabled = enabled,
        markdown = markdown,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/LabSupportPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs.builder
import com.pulumi.azurenative.devtestlab.kotlin.enums.EnableStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of a lab's support banner
 * @property enabled Is the lab support banner active/enabled at this time?
 * @property markdown The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
 */
public data class LabSupportPropertiesArgs(
    public val enabled: Output<Either<String, EnableStatus>>? = null,
    public val markdown: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs =
        com.pulumi.azurenative.devtestlab.inputs.LabSupportPropertiesArgs.builder()
            .enabled(
                enabled?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .markdown(markdown?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LabSupportPropertiesArgs].
 */
@PulumiTagMarker
public class LabSupportPropertiesArgsBuilder internal constructor() {
    private var enabled: Output<Either<String, EnableStatus>>? = null

    private var markdown: Output<String>? = null

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("bevceokamycjupoe")
    public suspend fun enabled(`value`: Output<Either<String, EnableStatus>>) {
        this.enabled = value
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("sergyrkkxorloqer")
    public suspend fun markdown(`value`: Output<String>) {
        this.markdown = value
    }

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("rbncslbibwemlwtk")
    public suspend fun enabled(`value`: Either<String, EnableStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("clseyinmadkclybc")
    public fun enabled(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab support banner active/enabled at this time?
     */
    @JvmName("byxsjwawfonfjxle")
    public fun enabled(`value`: EnableStatus) {
        val toBeMapped = Either.ofRight<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("idvrnfrvpykqkbfs")
    public suspend fun markdown(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.markdown = mapped
    }

    internal fun build(): LabSupportPropertiesArgs = LabSupportPropertiesArgs(
        enabled = enabled,
        markdown = markdown,
    )
}
